@@ -1,4 +1,4 @@
-`caps` <- function(y, nyrs=length(y)/2, f= 0.5)
+`caps` <- function(y, nyrs=length(y) * 2/3, f= 0.5)
 {
   y <- as.numeric(y)
   ## If as.numeric() does not signal an error, it is unlikely that
@@ -13,8 +13,13 @@
   if(!is.numeric(f) || length(f) != 1 || f < 0 || f > 1)
     stop("'f' must be a number between 0 and 1")
   
-  if(!is.numeric(nyrs) || length(nyrs) != 1 || nyrs <= 1)
-    stop("'nyrs' must be a number greater than 1")
+  if(!is.numeric(nyrs) || length(nyrs) != 1 || nyrs <= 0)
+    stop("'nyrs' must be a number greater than 0")
+  
+  # if nyrs is between 0 and 1 treat it as % spline.
+  # e,g, nyrs = 0.667 would be a 2/3 spline
+  if(nyrs <= 1 & nyrs > 0)
+    nyrs <- nyrs * nobs
   
   # some error checks
   ySpl <-.Call(dplR.c_caps_f,
